@@ -28,13 +28,11 @@
 #include <sys/types.h>
 
 #include <glib.h>
-#undef G_DISABLE_SINGLE_INCLUDES
 
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
 #include <gconf/gconf-client.h>
-#include <libgnome/gnome-help.h>
 
 #include "terminal-accels.h"
 #include "terminal-app.h"
@@ -109,25 +107,72 @@ terminal_util_show_error_dialog (GtkWindow *transient_parent, GtkWidget **weak_p
 
       gtk_window_present (GTK_WINDOW (*weak_ptr));
     }
-  }
+}
+
+static gboolean
+open_url (GtkWindow *parent,
+          const char *uri,
+          guint32 user_time,
+          GError **error)
+{
+  GdkScreen *screen;
+
+  if (parent)
+    screen = gtk_widget_get_screen (GTK_WIDGET (parent));
+  else
+    screen = gdk_screen_get_default ();
+
+  return gtk_show_uri (screen, uri, user_time, error);
+}
 
 void
 terminal_util_show_help (const char *topic, 
-                         GtkWindow  *transient_parent)
+                         GtkWindow  *parent)
 {
-  GError *err;
-
-  err = NULL;
-
-  gnome_help_display ("gnome-terminal.xml", topic, &err);
-  
-  if (err)
-    {
-      terminal_util_show_error_dialog (GTK_WINDOW (transient_parent), NULL,
-                                       _("There was an error displaying help: %s"),
-                                      err->message);
-      g_error_free (err);
+  GError *error = NULL;
+  const char *lang;
+  char *uri = NULL, *url;
+  guint i;
+ 
+  const char * const * langs = g_get_language_names ();
+  for (i = 0; langs[i]; i++) {
+    lang = langs[i];
+    if (strchr (lang, '.')) {
+      continue;
     }
+ 
+    uri = g_build_filename (TERM_DATADIR,
+                            "gnome", "help", "gnome-terminal",
+                            lang,
+                            "gnome-terminal.xml",
+                            NULL);
+					
+    if (g_file_test (uri, G_FILE_TEST_EXISTS)) {
+      break;
+    }
+
+    g_free (uri);
+    uri = NULL;
+  }
+
+  if (!uri)
+    return;
+
+  if (topic) {
+    url = g_strdup_printf ("ghelp://%s?%s", uri, topic);
+  } else {
+    url = g_strdup_printf ("ghelp://%s", uri);
+  }
+
+  if (!open_url (GTK_WINDOW (parent), url, gtk_get_current_event_time (), &error))
+    {
+      terminal_util_show_error_dialog (GTK_WINDOW (parent), NULL,
+                                       _("There was an error displaying help: %s"),
+                                      error->message);
+      g_error_free (error);
+    }
+
+  g_free (url);
 }
  
 /* sets accessible name and description for the widget */
@@ -167,9 +212,6 @@ terminal_util_open_url (GtkWidget *parent,
 {
   GError *error = NULL;
   char *uri;
-#if GTK_CHECK_VERSION (2, 13, 0)
-  GdkAppLaunchContext *context;
-#endif
 
   g_return_if_fail (orig_url != NULL);
 
@@ -193,22 +235,7 @@ terminal_util_open_url (GtkWidget *parent,
       g_assert_not_reached ();
     }
 
-#if GTK_CHECK_VERSION (2, 13, 0)
-  context = gdk_app_launch_context_new ();
-  gdk_app_launch_context_set_timestamp (context, user_time);
-
-  if (parent)
-    gdk_app_launch_context_set_screen (context, gtk_widget_get_screen (parent));
-  else
-    gdk_app_launch_context_set_screen (context, gdk_screen_get_default ());
-
-  g_app_info_launch_default_for_uri (uri, G_APP_LAUNCH_CONTEXT (context), &error);
-  g_object_unref (context);
-#else
-  g_app_info_launch_default_for_uri (uri, NULL, &error);
-#endif
-
-  if (error)
+  if (!open_url (GTK_WINDOW (parent), uri, user_time, &error))
     {
       terminal_util_show_error_dialog (GTK_WINDOW (parent), NULL,
                                        _("Could not open the address “%s”:\n%s"),
@@ -257,6 +284,31 @@ terminal_util_transform_uris_to_quoted_fuse_paths (char **uris)
     }
 }
 
+char *
+terminal_util_concat_uris (char **uris,
+                           gsize *length)
+{
+  GString *string;
+  gsize len;
+  guint i;
+
+  len = 0;
+  for (i = 0; uris[i]; ++i)
+    len += strlen (uris[i]) + 1;
+
+  if (length)
+    *length = len;
+
+  string = g_string_sized_new (len + 1);
+  for (i = 0; uris[i]; ++i)
+    {
+      g_string_append (string, uris[i]);
+      g_string_append_c (string, ' ');
+    }
+
+  return g_string_free (string, FALSE);
+}
+
 gboolean
 terminal_util_load_builder_file (const char *filename,
                                  const char *object_name,
